summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--include/llvm/Transforms/Scalar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/Transforms/Scalar.h b/include/llvm/Transforms/Scalar.h
index 91cc81a1b2..144db23670 100644
--- a/include/llvm/Transforms/Scalar.h
+++ b/include/llvm/Transforms/Scalar.h
@@ -45,11 +45,11 @@ Pass *createDeadCodeEliminationPass();
//===----------------------------------------------------------------------===//
//
// AgressiveDCE - This pass uses the SSA based Agressive DCE algorithm. This
// algorithm assumes instructions are dead until proven otherwise, which makes
// it more successful are removing non-obviously dead instructions.
//
-Pass *createAgressiveDCEPass();
+Pass *createAggressiveDCEPass();
//===----------------------------------------------------------------------===//
@@ -45,11 +45,11 @@ Pass *createDeadCodeEliminationPass();
//===----------------------------------------------------------------------===//
//
-// AgressiveDCE - This pass uses the SSA based Agressive DCE algorithm. This
+// AggressiveDCE - This pass uses the SSA based Aggressive DCE algorithm. This
// algorithm assumes instructions are dead until proven otherwise, which makes
// it more successful are removing non-obviously dead instructions.